@@ -4,10 +4,9 @@ CHROMEDRIVER_STORAGE_URL = 'https://chromedriver.storage.googleapis.com'
 ZIP_TYPE = '.zip'
 
 CHROMEDRIVER = 'chromedriver'
-FILE_NAME_CHROMEDRIVER = 'chromedriver'
-FILE_NAME_CHROMEDRIVER_EXE = 'chromedriver.exe'
+WEBDRIVER = 'webdriver'
 
-UL_VERSIONS_SELECTOR = '#sites-canvas-main-content > table > tbody > tr > td > div > div:nth-child(5) > ul'
+CSS_VERSIONS_SELECTOR_UL = 'ul.n8H08c:nth-child(5)'
 
 LATEST_STABLE_VERSION_STR = 'Latest stable release'
 LATEST_BETA_VERSION_STR = 'Latest beta release'
