@@ -59,7 +59,7 @@ class GetChromeDriver:
             raise GetChromeDriverError('error: could not connect to ' + constants.CHROMEDRIVER_CHROMIUM_URL)
 
         soup = BeautifulSoup(res.content, 'html.parser')
-        ul = soup.select_one(constants.UL_VERSIONS_SELECTOR)
+        ul = soup.select_one(constants.CSS_VERSIONS_SELECTOR_UL)
         for li in ul:
             li_text = li.text.replace(u'\u00A0', ' ')
             if self.__phases.stable == phase:
@@ -149,24 +149,24 @@ class GetChromeDriver:
         self.download_version(version, output_path, extract)
 
     def download_beta_version(self, output_path=None, extract=False) -> None:
-        """ Download the latest stable chromedriver version """
+        """ Download the latest beta chromedriver version """
 
         version = self.__latest_version_by_phase(self.__phases.beta)
         self.download_version(version, output_path, extract)
 
-    def download_version(self, version, path=None, extract=False) -> str:
+    def download_version(self, version, output_path=None, extract=False) -> str:
         """ Download a chromedriver version """
 
         self.__check_version(version)
 
-        if len(str(path)) == 0:
+        if len(str(output_path)) == 0:
             # on path == '',
             # ChromeDriver will be downloaded in the current dir
-            path = ''
-        elif not path:
+            output_path = ''
+        elif not output_path:
             # on path == None,
             # ChromeDriver will be downloaded at e.g. chromedriver/88.0.4324.96/bin/chromedriver.exe
-            path = self._default_output_path(version)
+            output_path = self._default_output_path(version)
 
         # on path == webdriver/bin (or any other dir name),
         # ChromeDriver will be downloaded at webdriver/bin/chromedriver.exe
@@ -184,9 +184,9 @@ class GetChromeDriver:
                     os.chmod(download_path + '/' + constants.CHROMEDRIVER, 0o755)
             return download_path
 
-        # Download the driver file and return the dir path of the driver file
+        # Download the driver file and return the relative dir path of the driver file
         url = self.version_url(version)
-        return download(url, path)
+        return download(url, output_path)
 
     def __check_url(self, url) -> None:
         """ Check if url is valid """
